==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Help/About/ts/About_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">Ü&amp;ber</translation>
    </message>
    <message>
        <location filename="../About.js" line="+62"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Revision:</source>
        <translation>Revision:</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 baut auf QCAD auf, einer freien (Open Source) Software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Das bedeutet, dass jeder &lt;a href=&apos;%1&apos;&gt;mithelfen&lt;/a&gt; kann!</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation>Teile dieser Software sind © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Die Veröffentlichung dieses Programms erfolgt in der Hoffnung, dass es Ihnen von Nutzen sein wird, aber OHNE JEDE GEWÄHRLEISTUNG - sogar ohne die implizite Gewährleistung der MARKTREIFE oder der EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>No information available</source>
        <translation>Keine Information verfügbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location line="-115"/>
        <location line="+108"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location line="-95"/>
        <location line="+99"/>
        <source>Qt Version:</source>
        <translation>Qt Version:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <location line="-109"/>
        <location line="+118"/>
        <location line="+12"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-128"/>
        <source>Build Date:</source>
        <translation>Erstellungsdatum:</translation>
    </message>
    <message>
        <source>From revision:</source>
        <translation type="obsolete">Revision:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Architecture:</source>
        <translation>Architektur:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Compiler:</source>
        <translation>Compiler:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 ist eine Applikation für computerunterstütztes Zeichnen (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 ist freie (Open Source) Software.</translation>
    </message>
    <message>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved!</source>
        <translation type="obsolete">Das bedeutet, dass jeder &lt;a href=&apos;%1&apos;&gt;mithelfen kann.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins und Skript Add-ons unterliegen ihrer jeweiligen Lizenz (siehe &quot;Plugins&quot; Reiter).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Alle Marken und Produktnamen sind Marken oder eingetragene Marken der jeweiligen Inhaber.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Teile dieser Software sind © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Teile dieser Software sind © 2012 Nokia Corporation und / oder ihrer Tochtergesellschaft(en).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Keine Plugins gefunden.</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inaktiv (Neustart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Testversion:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Datei:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Script Add-Ons</source>
        <translation>Skript Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Keine Script Add-ons gefunden.</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Credits</source>
        <translation>Beitragende</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>Ü&amp;ber...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmierung</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Templates</source>
        <translation>Vorlagen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Ikone</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testen, Rückmeldungen und kleinere Korrekturen</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">Über QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Beitragende</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Über Plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Über Skript Add-Ons</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Help/About/ts/About_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <source>&amp;About</source>
        <translation type="obsolete">Ü&amp;ber</translation>
    </message>
    <message>
        <location filename="../About.js" line="+63"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Revision:</source>
        <translation>Revision:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>License Key:</source>
        <translation>Lizenzschlüssel:</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 is based on QCAD, a free (open source) software.</source>
        <translation>%1 baut auf QCAD auf, einer freien (Open Source) Software.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved&lt;/a&gt;!</source>
        <translation>Das bedeutet, dass jeder &lt;a href=&apos;%1&apos;&gt;mithelfen&lt;/a&gt; kann!</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2016 The Qt Company Ltd.</source>
        <translation type="vanished">Teile dieser Software sind © 2008-2016 The Qt Company Ltd.</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2018 The Qt Company Ltd.</source>
        <translation type="vanished">Teile dieser Software sind © 2008-2018 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Portions of this software © %1 The Qt Company Ltd.</source>
        <translation>Teile dieser Software sind © %1 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.</source>
        <translation>Die Veröffentlichung dieses Programms erfolgt in der Hoffnung, dass es Ihnen von Nutzen sein wird, aber OHNE JEDE GEWÄHRLEISTUNG - sogar ohne die implizite Gewährleistung der MARKTREIFE oder der EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>No information available</source>
        <translation>Keine Information verfügbar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <location line="-128"/>
        <location line="+121"/>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
    <message>
        <location line="-111"/>
        <location line="+115"/>
        <source>Qt Version:</source>
        <translation>Qt Version:</translation>
    </message>
    <message>
        <source>Portions of this software © 2008-2017 The Qt Company Ltd.</source>
        <translation type="vanished">Teile dieser Software sind © 2008-2017 The Qt Company Ltd.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>License:</source>
        <translation>Lizenz:</translation>
    </message>
    <message>
        <location line="-125"/>
        <location line="+134"/>
        <location line="+11"/>
        <source>Internet:</source>
        <translation>Internet:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Build Date:</source>
        <translation>Erstellungsdatum:</translation>
    </message>
    <message>
        <source>From revision:</source>
        <translation type="obsolete">Revision:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Architecture:</source>
        <translation>Architektur:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Compiler:</source>
        <translation>Compiler:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is an application for computer-aided design (CAD).</source>
        <translation>%1 ist eine Applikation für computerunterstütztes Zeichnen (CAD).</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>%1 is free (open source) software.</source>
        <translation>%1 ist freie (Open Source) Software.</translation>
    </message>
    <message>
        <source>This means that everyone can &lt;a href=&apos;%1&apos;&gt;get involved!</source>
        <translation type="obsolete">Das bedeutet, dass jeder &lt;a href=&apos;%1&apos;&gt;mithelfen kann.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Plugins and script add-ons are subject to their respective license (see &apos;Plugins&apos; tab).</source>
        <translation>Plugins und Skript Add-ons unterliegen ihrer jeweiligen Lizenz (siehe &quot;Plugins&quot; Reiter).</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All brand or product names are trademarks or registered trademarks of their respective holders.</source>
        <translation>Alle Marken und Produktnamen sind Marken oder eingetragene Marken der jeweiligen Inhaber.</translation>
    </message>
    <message>
        <source>Portions of this software © 2013 Digia Plc.</source>
        <translation type="vanished">Teile dieser Software sind © 2013 Digia Plc.</translation>
    </message>
    <message>
        <source>Portions of this software © 2012 Nokia Corporation and/or its subsidiary(-ies).</source>
        <translation type="vanished">Teile dieser Software sind © 2012 Nokia Corporation und / oder ihrer Tochtergesellschaft(en).</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>No plugins found.</source>
        <translation>Keine Plugins gefunden.</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inactive (restart)</source>
        <translation>Inaktiv (Neustart)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Trial Version:</source>
        <translation>Testversion:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File:</source>
        <translation>Datei:</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Error:</source>
        <translation>Fehler:</translation>
    </message>
    <message>
        <source>Community Edition</source>
        <translation type="vanished">Community Edition</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Script Add-Ons</source>
        <translation>Skript Add-Ons</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No script add-ons found.</source>
        <translation>Keine Script Add-ons gefunden.</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Credits</source>
        <translation>Beitragende</translation>
    </message>
    <message>
        <location filename="../AboutInit.js" line="+2"/>
        <source>&amp;About...</source>
        <translation>Ü&amp;ber...</translation>
    </message>
</context>
<context>
    <name>AboutCredits</name>
    <message>
        <location filename="../AboutCredits.js" line="+4"/>
        <source>Programming</source>
        <translation>Programmierung</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Templates</source>
        <translation>Vorlagen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Icons</source>
        <translation>Ikone</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Testing, Feedback and Minor Fixes</source>
        <translation>Testen, Rückmeldungen und kleinere Korrekturen</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About QCAD</source>
        <translation type="obsolete">Über QCAD</translation>
    </message>
    <message>
        <location filename="../AboutDialog.ui" line="+105"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation type="vanished">about:blank</translation>
    </message>
    <message>
        <location line="+134"/>
        <source>Plugins</source>
        <translation>Plugins</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Credits</source>
        <translation>Beitragende</translation>
    </message>
    <message>
        <source>About Plugins</source>
        <translation type="obsolete">Über Plugins</translation>
    </message>
    <message>
        <source>About Script Add-Ons</source>
        <translation type="obsolete">Über Skript Add-Ons</translation>
    </message>
</context>
</TS>
